// src/stores/memory.ts
var MemoryStore = class {
  state;
  name = "memory";
  constructor(config) {
    this.state = config.persistentMap;
  }
  async get(key) {
    const value = this.state.get(key);
    if (!value) {
      return Promise.resolve(void 0);
    }
    if (value.expires <= Date.now()) {
      await this.remove(key);
    }
    return Promise.resolve(value.entry);
  }
  async set(key, entry) {
    this.state.set(key, {
      expires: entry.staleUntil,
      entry
    });
    return Promise.resolve();
  }
  async remove(keys) {
    const cacheKeys = Array.isArray(keys) ? keys : [keys];
    for (const key of cacheKeys) {
      this.state.delete(key);
    }
    return Promise.resolve();
  }
};

// src/stores/redis.ts
var RedisStore = class {
  redis;
  name = "redis";
  prefix;
  constructor(config) {
    this.redis = config.redis;
    this.prefix = config.prefix || "sbch";
  }
  buildCacheKey(key) {
    return [this.prefix, key].join("::");
  }
  async get(key) {
    const res = await this.redis.get(this.buildCacheKey(key));
    if (!res) return;
    return JSON.parse(res);
  }
  async set(key, entry) {
    await this.redis.set(
      this.buildCacheKey(key),
      JSON.stringify(entry),
      "PXAT",
      entry.staleUntil
    );
  }
  async remove(keys) {
    const cacheKeys = (Array.isArray(keys) ? keys : [keys]).map(
      (key) => this.buildCacheKey(key).toString()
    );
    this.redis.del(...cacheKeys);
  }
};
export {
  MemoryStore,
  RedisStore
};
//# sourceMappingURL=stores.js.map